@@ -25,8 +25,13 @@ module type S = sig
   val min_elt        : t -> elt option
   val max_elt        : t -> elt option
   val choose         : t -> elt option
+  val choose_exn     : t -> elt
   val split          : t -> elt -> t * bool * t
   val of_list        : elt list -> t
   val to_list        : t -> elt list
   val find           : t -> f:(elt -> bool) -> elt option
+
+  val union_all : t list -> t
+  val union_map : 'a list -> f:('a -> t) -> t
+
 end
